@@ -5,12 +5,12 @@ def _as_pairs(
     x: Union[
         Tuple[Union[Tuple[int, int], int], ...],
         int,
-        List[Tuple[Union[int, numpy.int64], Union[int, numpy.int64]]],
+        List[Tuple[numpy.int64, numpy.int64]],
     ],
     ndim: int,
     as_index: bool,
 ):
     """
-    usage.skimage: 6
+    usage.skimage: 5
     """
     ...
