@@ -1,18 +1,14 @@
 from typing import *
 
 # usage.skimage: 2
-# usage.sklearn: 3
+# usage.sklearn: 4
 LinAlgError: object
 
-# usage.dask: 4
-_umath_linalg: object
 
-
-def det(a: Union[dask.array.core.Array, numpy.ndarray]):
+def det(a: numpy.ndarray):
     """
     usage.skimage: 5
     usage.sklearn: 1
-    usage.dask: 2
     """
     ...
 
@@ -25,13 +21,6 @@ def eig(a: numpy.ndarray):
     ...
 
 
-def eigvals(a: Union[numpy.ndarray, dask.array.core.Array]):
-    """
-    usage.dask: 2
-    """
-    ...
-
-
 def eigvalsh(a: numpy.ndarray):
     """
     usage.skimage: 2
@@ -42,6 +31,7 @@ def eigvalsh(a: numpy.ndarray):
 def inv(a: numpy.ndarray):
     """
     usage.skimage: 7
+    usage.sklearn: 6
     """
     ...
 
@@ -49,7 +39,6 @@ def inv(a: numpy.ndarray):
 def lstsq(a: numpy.ndarray, b: numpy.ndarray):
     """
     usage.sklearn: 2
-    usage.dask: 3
     """
     ...
 
@@ -62,15 +51,13 @@ def matrix_rank(M: numpy.ndarray):
 
 
 def norm(
-    x: object,
-    ord: Union[None, int, float, Literal["nuc", "fro"]] = ...,
-    axis: Union[None, int, Tuple[int, ...]] = ...,
-    keepdims: bool = ...,
+    x: numpy.ndarray,
+    ord: Union[float, int, Literal["fro"]] = ...,
+    axis: Union[None, int] = ...,
 ):
     """
     usage.skimage: 8
-    usage.sklearn: 22
-    usage.dask: 32
+    usage.sklearn: 45
     """
     ...
 
@@ -82,13 +69,6 @@ def pinv(a: numpy.ndarray):
     ...
 
 
-def qr(a: numpy.ndarray):
-    """
-    usage.dask: 5
-    """
-    ...
-
-
 def slogdet(a: numpy.ndarray):
     """
     usage.sklearn: 1
@@ -106,8 +86,7 @@ def solve(a: numpy.ndarray, b: numpy.ndarray):
 def svd(a: numpy.ndarray):
     """
     usage.skimage: 7
-    usage.sklearn: 3
-    usage.dask: 5
+    usage.sklearn: 6
     """
     ...
 
@@ -115,7 +94,4 @@ def svd(a: numpy.ndarray):
 class LinAlgError:
 
     # usage.sklearn: 2
-    args: Tuple[
-        Literal["The kernel, DotProduct(sigma_0=1), is not returnin"],
-        Literal["3-th leading minor of the array is not positive de"],
-    ]
+    args: Tuple[str, str]
