@@ -4,7 +4,13 @@ from typing import *
 def average(a: numpy.ma.core.MaskedArray, weights: Union[numpy.ndarray, None]):
     """
     usage.sklearn: 8
-    usage.dask: 1
+    """
+    ...
+
+
+def masked_all(shape: Tuple[int, ...]):
+    """
+    usage.pandas: 14
     """
     ...
 
