@@ -1,6 +1,6 @@
 from typing import *
 
-# usage.sample_usage: 1
+# usage.sample-usage: 1
 Chebyshev: object
 
 
@@ -8,6 +8,6 @@ class Chebyshev:
     @classmethod
     def basis(cls, /, deg: int):
         """
-        usage.sample_usage: 1
+        usage.sample-usage: 1
         """
         ...
