@@ -1,50 +1,48 @@
 from typing import *
 
+# usage.pandas: 4
 # usage.skimage: 1
-# usage.sklearn: 5
-# usage.dask: 4
+# usage.sklearn: 22
 RandomState: object
 
+# usage.pandas: 15
 # usage.skimage: 2
 # usage.xarray: 2
-# usage.dask: 20
 choice: object
 
-# usage.sample_usage: 1
+# usage.sample-usage: 1
 # usage.skimage: 1
-# usage.sklearn: 16
+# usage.sklearn: 18
 mtrand: object
 
-# usage.dask: 1
-multinomial: object
-
+# usage.pandas: 6
 # usage.skimage: 5
-# usage.dask: 11
+# usage.sklearn: 1
 normal: object
 
 # usage.skimage: 18
 rand: object
 
-# usage.skimage: 13
+# usage.pandas: 84
+# usage.skimage: 14
+# usage.sklearn: 8
 # usage.xarray: 2
-# usage.sklearn: 3
-# usage.dask: 71
 randint: object
 
+# usage.pandas: 4
 # usage.skimage: 10
 # usage.xarray: 6
 randn: object
 
-# usage.xarray: 3
-# usage.dask: 15
+# usage.pandas: 11
+# usage.xarray: 4
 random: object
 
 # usage.skimage: 4
-# usage.dask: 1
 seed: object
 
-# usage.skimage: 24
-# usage.xarray: 1
+# usage.pandas: 2
+# usage.skimage: 22
 # usage.sklearn: 4
-# usage.dask: 1
+# usage.xarray: 1
 uniform: object
