@@ -3,7 +3,7 @@ from typing import *
 
 def assert_(val: Union[bool, numpy.bool_]):
     """
-    usage.skimage: 91
+    usage.skimage: 78
     """
     ...
 
@@ -11,31 +11,24 @@ def assert_(val: Union[bool, numpy.bool_]):
 def assert_allclose(
     actual: object,
     desired: object,
-    rtol: Union[float, int] = ...,
-    atol: Union[float, int] = ...,
+    rtol: Union[int, float] = ...,
+    atol: Union[int, float] = ...,
     err_msg: str = ...,
 ):
     """
-    usage.skimage: 169
-    usage.xarray: 27
-    usage.sklearn: 307
+    usage.skimage: 158
+    usage.sklearn: 760
+    usage.xarray: 38
     """
     ...
 
 
 def assert_almost_equal(
-    actual: object,
-    desired: object,
-    decimal: int = ...,
-    err_msg: Literal[
-        "Point is not on expected circle",
-        "Point is not on expected unit circle",
-        "Unexpected std",
-    ] = ...,
+    actual: object, desired: object, decimal: int = ..., err_msg: str = ...
 ):
     """
-    usage.skimage: 340
-    usage.sklearn: 244
+    usage.skimage: 333
+    usage.sklearn: 965
     """
     ...
 
@@ -48,12 +41,11 @@ def assert_approx_equal(actual: numpy.float64, desired: numpy.float64):
 
 
 def assert_array_almost_equal(
-    x: object, y: object, decimal: int = ..., err_msg: str = ...
+    x: object, y: object, decimal: Union[int, bool] = ..., err_msg: str = ...
 ):
     """
-    usage.skimage: 107
-    usage.sklearn: 641
-    usage.dask: 1
+    usage.skimage: 69
+    usage.sklearn: 1569
     """
     ...
 
@@ -70,37 +62,37 @@ def assert_array_almost_equal_nulp(
 
 def assert_array_equal(x: object, y: object):
     """
-    usage.skimage: 495
-    usage.xarray: 322
-    usage.sklearn: 562
-    usage.dask: 28
+    usage.skimage: 430
+    usage.sklearn: 1475
+    usage.xarray: 400
     """
     ...
 
 
 def assert_array_less(
-    x: Union[int, float, numpy.ndarray, numpy.float64],
-    y: Union[numpy.ndarray, int, float, numpy.float64],
+    x: Union[numpy.ndarray, float, int, numpy.float64],
+    y: Union[numpy.float64, float, numpy.ndarray, int],
 ):
     """
     usage.skimage: 20
-    usage.sklearn: 9
+    usage.sklearn: 18
     """
     ...
 
 
 def assert_equal(actual: object, desired: object):
     """
-    usage.skimage: 664
-    usage.xarray: 21
-    usage.dask: 26
+    usage.skimage: 630
+    usage.sklearn: 27
+    usage.xarray: 40
     """
     ...
 
 
-def assert_no_warnings():
+def assert_no_warnings(*args: Literal["v", "t"]):
     """
     usage.skimage: 1
+    usage.sklearn: 1
     """
     ...
 
@@ -108,5 +100,6 @@ def assert_no_warnings():
 def assert_warns(warning_class: type, *args: Literal["v", "t"]):
     """
     usage.skimage: 5
+    usage.sklearn: 1
     """
     ...
