@@ -210,6 +210,16 @@ def signature(fn):
     return inspect.signature(fn)
 
 
+def safe_signature(fn):
+    """
+    If fn is hashable, cache it, otherwise dont use cached version
+    """
+    try:
+        hash(fn)
+    except Exception:
+        return inspect.signature(fn)
+    return signature(fn)
+
 @dataclasses.dataclass
 class Bound:
     """
@@ -236,7 +246,7 @@ class Bound:
     @classmethod
     def create(cls, fn, args, kwargs) -> Optional[Bound]:
         try:
-            sig = signature(fn)
+            sig = safe_signature(fn)
         except ValueError:
             return None
         try:
@@ -433,7 +443,7 @@ class Stack:
         }
         if val in COMPARISONS:
             self.process(
-                (self.TOS, self.TOS1) if "in" not in val else (self.TOS),
+                (self.TOS, self.TOS1) if "in" not in val else (self.TOS,),
                 COMPARISONS[val],
                 # "in" and "not in" are reversed
                 (self.TOS1, self.TOS,) if "in" not in val else (self.TOS, self.TOS1,),
